"pop",
"dup",
"dup2",
"rot2",
"rot3",
"rot4",
"number_0",
"number_1",
"number_pos",
"number_neg",
"number",
"string",
"closure",
"newarray",
"newobject",
"newregexp",
"undef",
"null",
"true",
"false",
"this",
"global",
"current",
"initlocal",
"getlocal",
"setlocal",
"dellocal",
"initvar",
"defvar",
"hasvar",
"getvar",
"setvar",
"delvar",
"in",
"initprop",
"initgetter",
"initsetter",
"getprop",
"getprop_s",
"setprop",
"setprop_s",
"delprop",
"delprop_s",
"iterator",
"nextiter",
"eval",
"call",
"new",
"typeof",
"pos",
"neg",
"bitnot",
"lognot",
"inc",
"dec",
"postinc",
"postdec",
"mul",
"div",
"mod",
"add",
"sub",
"shl",
"shr",
"ushr",
"lt",
"gt",
"le",
"ge",
"eq",
"ne",
"stricteq",
"strictne",
"jcase",
"bitand",
"bitxor",
"bitor",
"instanceof",
"throw",
"try",
"endtry",
"catch",
"endcatch",
"with",
"endwith",
"debugger",
"jump",
"jtrue",
"jfalse",
"return",
"line",
